**************************
Tools
**************************

``piel`` aims to provide an integrated workflow to co-design photonics and electronics. It does not aim to replace the individual functionality of each design tool, but rather provide a glue to easily connect them all together and extract the system performance.


This package provides interconnection functions to easily co-design
microelectronics through the functionality of multiple electronic and photonic design tools.

.. figure:: ../../_static/img/piel_microservice_structure.png
   :alt: `piel` microservices structure.

.. toctree::
    :caption: Contents:

    dependencies/index
    integration/index
